import { nextTick, Ref } from 'vue';


/**
 * 获取 El-Table的数据并处理total和loading
 * @param apiFunction 请求的接口函数
 * @param query 请求参数
 * @param tableData El-Table的数据
 * @param total El-Table数据的总条数
 * @param loading El-Table的loading状态
 */
export async function useElTableData(apiFunction: Function, query: any, tableData: Ref, total: Ref, loading: Ref) {
  loading.value = true;
  try {
    const response = await apiFunction(query);
    total.value = response.total;
    tableData.value = response.data;
  } catch (error) {
    console.log('error=>', error);
  } finally {
    loading.value = false;
    await nextTick();
    // 触发窗口 resize 事件
    window.dispatchEvent(new Event('resize'));
  }
}
